@@ -99,7 +99,7 @@
 	}
 	if (!group) {
 		LSD=" "
-		comb <- combn(ntr, 2)
+		comb <- utils::combn(ntr, 2)
 		nn <- ncol(comb)
 		dif <- rep(0, nn)
 		pvalue <- dif
