@@ -65,7 +65,7 @@
 		groups <- data.frame(groups[,1:3])
 	}
 	else {
-		comb <-combn(ntr,2)
+		comb <-utils::combn(ntr,2)
 		nn<-ncol(comb)
 		dif<-rep(0,nn)
 		sig<-NULL
